#! /usr/bin/env node
const chalk = require('chalk');
const program = require('commander');
const updateNotifier = require('update-notifier');
const pkg = require('../package.json');
const loadConfig = require('mints-load-config');
const mints = require('./mints');

updateNotifier({ pkg }).notify();

/*
* basic
*/
program
  .version(pkg.version, '-v, --version')
  .usage(`${chalk.greenBright('<command>')} [option]`)
  .description(`${chalk.dim.cyan('Thank you for using mints!')}`);

/*
* command
*/
program
  .command('start')
  .description('run app in development mode')
  .action(function() {
    run('start');
  });

program
  .command('build')
  .description('build app in production mode')
  .action(function() {
    run('build')
  });

/*
* option
*/
program
  .option('-c, --config <path>', 'use custom path to config file');

/*
* help
*/
program
  .on('--help', () => {
    console.log();
    console.log(`  Issue: ${chalk.cyanBright('https://github.com/mintsweet/mints/issues')}`);
    console.log();
  });

/*
* parse
*/
program
  .parse(process.argv);

/*
* run
*/
function run(cmd) {
  let options = {};
  if (program.config) {
    options = loadConfig(program.config);
  } else {
    options = loadConfig();
  }

  const app = mints(options);

  switch(cmd) {
    case 'start':
      app.start();
    break;
    case 'build':
      app.build();
    break;
    default:
      console.log();
      console.log('Unkown command!');
    break;
  }
}