const EventEmitter = require('events');
const webpack = require('webpack');
const createConfig = require('./create-config');
const createServer = require('./create-server');

class Mints extends EventEmitter {
  constructor(options) {
    super(options);
    this.options = Object.assign({
      host: process.env.HOST || options.host || '0.0.0.0',
      port: process.env.PORT || options.port || 4255,
    }, options);
    this.webpackFlows = [];
  }

  createWebpackConfig(mode) {
    this.usePreset();
    this.webpackConfig = createConfig(Object.assign({ mode }, this.options));
    this.webpackFlows.forEach(flow => flow(this.webpackConfig));
    return this.webpackConfig;
  }

  addWebpackFlow(fn) {
    this.webpackFlows.push(fn);
  }

  start() {
    const webpackConfig = this.createWebpackConfig('development');
    this.createCompiler(webpackConfig);
    return createServer(this.compiler, this.options);
  }

  build() {
    const webpackConfig = this.createWebpackConfig('production');
    this.createCompiler(webpackConfig);
    return this.compiler.run();
  }
  
  createCompiler(webpackConfig) {
    this.compiler = webpack(webpackConfig);
    return this;
  }

  usePreset() {
    const presetContext = {
      extendWebpack: this.addWebpackFlow.bind(this)
    }
    let presets = this.options.presets;
    if (presets) {
      presets.forEach(preset => preset(presetContext))
    }
  }
}

module.exports = options => new Mints(options);